@@ -9,20 +9,22 @@
     :license: BSD, see LICENSE for details
 """
 from __future__ import absolute_import, division, print_function, with_statement
+from __future__ import unicode_literals
 
-from functools import wraps
+from distutils.version import StrictVersion
 import unittest
 import collections
 import subprocess
 import os
+import sys
 
-from . import log
 import logging
 
 logger = logging.getLogger(__name__)
 
 
 class tmux(object):
+
     ''':py:mod:`subprocess` for :term:`tmux(1)`.
 
     Usage:
@@ -39,7 +41,7 @@ class tmux(object):
     '''
 
     def __init__(self, *args, **kwargs):
-        cmd = ['tmux']
+        cmd = [which('tmux')]
         cmd += args  # add the command arguments to cmd
         cmd = [str(c) for c in cmd]
 
@@ -52,26 +54,29 @@ class tmux(object):
                 stderr=subprocess.PIPE
             )
             self.process.wait()
-            stdout, stderr = self.process.stdout.read(), self.process.stderr.read()
+            stdout = self.process.stdout.read()
+            stderr = self.process.stderr.read()
         except Exception as e:
             logger.error('Exception for %s: \n%s' % (
                 cmd,
                 e.message)
             )
-        self.stdout = stdout.split('\n')
-        self.stdout = filter(None, self.stdout)  # filter empty values
+        self.stdout = stdout.decode().split('\n')
+        self.stdout = list(filter(None, self.stdout))  # filter empty values
 
-        self.stderr = stderr.split('\n')
-        self.stderr = filter(None, self.stderr)  # filter empty values
+        self.stderr = stderr.decode().split('\n')
+        self.stderr = list(filter(None, self.stderr))  # filter empty values
 
         if 'has-session' in cmd and len(self.stderr):
             if not self.stdout:
                 self.stdout = self.stderr[0]
 
-        logging.debug('self.stdout for %s: \n%s' % (' '.join(cmd), self.stdout))
+        logging.debug('self.stdout for %s: \n%s' %
+                      (' '.join(cmd), self.stdout))
 
 
 class TmuxMappingObject(collections.MutableMapping):
+
     '''
     Base: :py:class:`collections.MutableMapping`
 
@@ -105,6 +110,7 @@ class TmuxMappingObject(collections.MutableMapping):
 
 
 class TmuxRelationalObject(object):
+
     '''
     Manages collection of child objects  (a :class:`Server` has a collection of
     :class:`Session` objects, a :class:`Session` has collection of
@@ -114,7 +120,7 @@ class TmuxRelationalObject(object):
     ``self.children``, ``self.childIdAttribute`` and ``self.list_children``.
 
     ================ ================== ===================== ============================
-    Object           ``.children``      ``.childIdAttribute`` ``.list_children``
+    Object           ``.children``      ``.childIdAttribute`` method
     ================ ================== ===================== ============================
     :class:`Server`  ``self._sessions`` 'session_id'          :meth:`Server.list_sessions`
     :class:`Session` ``self._windows``  'window_id'           :meth:`Session.list_windows`
@@ -174,7 +180,7 @@ class TmuxRelationalObject(object):
         :type id: string
         :rtype: object
         '''
-        for child in self.list_children():
+        for child in self.children:
             if child[self.childIdAttribute] == id:
                 return child
             else:
@@ -201,11 +207,44 @@ def which(exe=None):
             full_path = os.path.join(path, exe)
             if os.access(full_path, os.X_OK):
                 return full_path
-        log.trace(
+        raise Exception(
             '{0!r} could not be found in the following search '
             'path: {1!r}'.format(
                 exe, search_path
             )
         )
-    log.trace('No executable was passed to be searched by which')
+    logger.error('No executable was passed to be searched by which')
     return None
+
+
+def version():
+    proc = tmux('-V')
+
+    if proc.stderr:
+        raise Exception(proc.stderr)
+
+    version = proc.stdout[0].split('tmux ')[1]
+
+    if StrictVersion(version) <= StrictVersion("1.7"):
+        raise Exception(
+            'tmuxp only supports tmux 1.8 and greater. This system'
+            ' has %s installed. Upgrade your tmux to use tmuxp.' % version
+        )
+    return version
+
+
+# http://www.rfk.id.au/blog/entry/preparing-pyenchant-for-python-3/
+try:
+    unicode = unicode
+except NameError:
+    # 'unicode' is undefined, must be Python 3
+    str = str
+    unicode = str
+    bytes = bytes
+    basestring = (str, bytes)
+else:
+    # 'unicode' exists, must be Python 2
+    str = str
+    unicode = unicode
+    bytes = str
+    basestring = basestring
